@@ -190,6 +190,9 @@ static const gchar *const author_credits[] = {
   "Chao-Hsiung Liao <j_h_liau yahoo com tw>",
   "Žygimantas Beručka <zygis gnome org>",
   "Gabor Kelemen <kelemeng gnome hu>",
+  "Telsa Gwynne <hobbit aloss ukuu org uk>",
+  "Slobodan D. Sredojevic <ssl uns ns ac yu>",
+  "Baris Cicek <baris teamforce name tr>",
   NULL
 };
 
